import pandas as pd


class Database:
    def __init__(self, file_path):
        self.data = pd.read_csv(file_path)

    def get_data(self):
        return self.data

    def get_unique_countries(self):
        return sorted(self.data['region'].unique())

    def top_ten_songs(self, country):
        country_data = self.data[self.data['region'] == country]
        sorted_data = country_data.sort_values(by='rank')[:10][['title', 'artist', 'url']]
        top_ten = [(rank, song, artist, url) for rank, (song, artist, url) in enumerate(sorted_data.values, start=1)]
        return top_ten

    def search_songs(self, song):
        result = []
        search_data = self.data[self.data['title'].str.contains(song, case=False, na=False)]
        for _, row in search_data.iterrows():
            result.append((row['title'], row['url']))
        return result

    def top_five_streams(self, artist):
        artist_data = self.data[self.data['artist'] == artist].drop_duplicates(subset=['title'])
        top_five = artist_data.sort_values(by='streams', ascending=False)[:5][['title', 'streams']]
        top_five['streams'] = top_five['streams'].apply(lambda x: int(x))
        top_five['rank'] = range(1, len(top_five) + 1)
        return [(row['rank'], row['title'], row['streams']) for _, row in top_five.iterrows()]

    def get_top_songs_by_rank(self, country):
        country_data = self.data[self.data['region'] == country]
        sorted_data = country_data.sort_values(by='rank')[:10][['title', 'artist', 'streams']]
        top_songs = [{'rank': rank, 'title': song, 'artist': artist, 'streams': streams} for
                     rank, (song, artist, streams) in enumerate(sorted_data.values, start=1)]
        return top_songs
