import matplotlib.pyplot as plt
import pandas as pd
from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
import re
import seaborn as sns


class Graph:
    def __init__(self, data):
        self.data = data

    def clean_artist_name(self, artist_name):
        # Remove invalid characters from artist name
        cleaned_name = re.sub(r'[^\w\s]', '', artist_name)
        return cleaned_name

    def plot_top_songs_by_rank(self, country, frame):
        filtered_data = self.data[self.data['region'] == country]
        top_songs = filtered_data.groupby('title')['rank'].min().sort_values(ascending=True)[:10]

        fig, ax = plt.subplots(figsize=(8, 6))
        ax.barh(top_songs.index, top_songs.values)
        ax.set_xlabel('Rank')
        ax.set_ylabel('Song Title')
        ax.set_title(f'Top 10 Songs in {country} by Rank')
        ax.invert_yaxis()
        plt.tight_layout()

        canvas = FigureCanvasTkAgg(fig, master=frame)
        canvas.draw()
        canvas.get_tk_widget().pack(side='left')

    def plot_top_artists_by_streams(self, country, frame):
        filtered_data = self.data[self.data['region'] == country].copy()
        filtered_data['artist'] = filtered_data['artist'].apply(self.clean_artist_name)

        top_artists = filtered_data.groupby('artist')['streams'].sum().nlargest(10)
        top_artists = top_artists.reset_index()

        fig, ax = plt.subplots(figsize=(8, 6))
        sns.barplot(x='streams', y='artist', data=top_artists, palette='viridis')
        ax.set_xlabel('Streams')
        ax.set_ylabel('Artist')
        ax.set_title(f'Top 10 Artists by Streams in {country}')
        plt.tight_layout()

        canvas = FigureCanvasTkAgg(fig, master=frame)
        canvas.draw()
        canvas.get_tk_widget().pack(side='right')



