# Spotify Country Analyzer

## Description

The Spotify Country Analyzer is a graphical user interface (GUI) application that allows users to analyze and visualize Spotify data based on different countries. The application provides features such as filtering songs by country, displaying top ten songs, searching for specific songs, and plotting graphs to analyze the data. The GUI provides an interactive interface for users to explore and understand Spotify music trends across different countries.


[CSV FILES(NEEDED)](https://www.kaggle.com/datasets/dhruvildave/spotify-charts)
![Spotify Country Analyzer Screenshot](app_model.jpg)


## Data Sources

The application utilizes a dataset in CSV format containing Spotify charts data. The dataset includes information about the ranking, title, artist, streams, and region (country) of songs. The data is used to analyze and visualize the popularity of songs and artists in different countries.

Data Source: [Spotify Charts Dataset](https://www.kaggle.com/datasets/dhruvildave/spotify-charts)

## Running the Application

### Dependencies

The application requires the following dependencies:

- Python (version 3.10)
- Tkinter (included in Python standard library)
- Pandas (install using `pip install pandas`)
- Matplotlib (install using `pip install matplotlib`)
- Seaborn (install using `pip install seaborn`)
- tkintermapview (install using `pip install tkintermapview`)

### How to Run

1. Clone the repository or download the source code.
2. Open a terminal or command prompt.
3. Navigate to the project directory.
4. download this csv files [csv](https://www.kaggle.com/datasets/dhruvildave/spotify-charts)
5. put it into this SpotifyCountryAnalyze repository
6. Run the following command: python main.py
7. The Spotify Country Analyzer GUI will open, and you can start interacting with the application.

## Design

### UML Class Diagram

![Spotify Country Analyzer Screenshot](uml_dia.jpg)

### Sequence Diagram

![Spotify Country Analyzer Screenshot](sequence_dia.jpg)

## Design Patterns Used

The application utilizes the following design patterns:

- **MVC (Model-View-Controller)**: The application follows the MVC pattern to separate the presentation logic (View) from the data and application logic (Model) using a Controller as an intermediary. The GUI components (View) are decoupled from the data handling and analysis (Model), enabling easier maintenance and extensibility.

- **Factory Method**: The application uses the Factory Method pattern to create instances of the Graph class. The factory method encapsulates the object creation logic, allowing the Graph class to be instantiated with different configurations based on the user's selection.

## Graph Algorithm Used

The application models the problem of analyzing top songs and artists by country as a graph problem. It involves analyzing the relationships between songs, artists, and their associated attributes such as rank and streams. The application uses graph algorithms to determine the top songs by rank and the top artists by streams in a selected country.

Algorithm Used: The algorithm used to solve this graph problem is based on sorting and filtering the data based on specified criteria such as rank and streams. It involves grouping the data by song title or artist and applying sorting and aggregation operations to identify the top songs and artists.

## Other Information

The application makes use of the following libraries and packages:

- Pandas: A powerful data manipulation and analysis library used for loading, filtering, and analyzing the Spotify charts dataset.
- Matplotlib: A plotting library used to create bar plots and visualize the top songs and artists.
- Seaborn: A statistical data visualization library built on top of Matplotlib. It enhances the visual aesthetics of the plots.
- tkintermapview: A library used to display a map view within the GUI, showing the selected country's location.

During the development of this application, I gained


